package org.nst.pasientlink.authenticator.admin.command;

/**
 * <p>Title: UserCreateCommand </p>
 * <p>Description: logic for UserCreateCommand pages</p>
 * <p>Copyright: Copyright (c) 2002</p>
 * <p>Company: </p>
 * @author unascribed
 * @version 1.0
 */
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.apache.velocity.context.Context;
import org.apache.velocity.app.tools.*;
import org.nst.pasientlink.authenticator.admin.Controller;

public class UserCreateCommand extends Command {
   // constants
   public static final String TEMPLATE_NAME = "user_create.vm";    //Name of the Template
   public static final String TEMPLATE_NAME_RECEIPT = "user_create_receipt.vm"; // Receipt after creating user
   private static final String PARAMETER_OPTION = "option";
   private static final String PARAMETER_OPTION_NEW_PASSWORD = "Generate new password";
   private static final String PARAMETER_OPTION_CREATE_USER = "Create user";
   private static final String PARAMETER_USERID = "userID";
   private static final String PARAMETER_PASSWORD = "password";
   private static final String PARAMETER_DESCRIPTION = "description";
   private static final String PARAMETER_GSMSUBSCRIBER_ID = "GSMSubscriberID";
   private static final String RETURN_VALUE_USER_EXISTS = "USER_EXISTS";
   private static final String RETURN_VALUE_ERROR_CREATING_USER = "ERROR_CREATING_USER";
   private static final String RETURN_VALUE_MISSING_PARAMETERS = "MISSING_PARAMETERS";

   // instance variables
   String myOption;
   String myUserID;
   String myPassword;
   String myDescription;
   String myGSMSubscriberID;

   public UserCreateCommand( HttpServletRequest req, HttpServletResponse resp )
   {
       super(req, resp);
   }

   public String exec(Context ctx)
   {
      String returnTemplate = TEMPLATE_NAME;
      myOption = request.getParameter(this.PARAMETER_OPTION);
      myUserID = request.getParameter(this.PARAMETER_USERID);
      myPassword = request.getParameter(this.PARAMETER_PASSWORD);
      myDescription = request.getParameter(this.PARAMETER_DESCRIPTION);
      myGSMSubscriberID = request.getParameter(this.PARAMETER_GSMSUBSCRIBER_ID);
      if(myOption == null || myOption.length() == 0) {
         ctx.put(this.PARAMETER_PASSWORD, getNextPassword());
      }
      else if(myOption.equalsIgnoreCase(this.PARAMETER_OPTION_NEW_PASSWORD)) {
         putUserParameters(ctx);
         ctx.put(this.PARAMETER_PASSWORD, getNextPassword());
      }
      else if(myOption.equalsIgnoreCase(this.PARAMETER_OPTION_CREATE_USER)) {
         putUserParameters(ctx);
         if(myUserID != null && myUserID.trim().length() != 0 &&
            myPassword != null && myPassword.trim().length() != 0 &&
            myDescription != null && myPassword.trim().length() != 0 &&
            myGSMSubscriberID != null && myGSMSubscriberID.trim().length() != 0) {

            if(this.getAuthenticatorStorage().userExists(myUserID)) {
               ctx.put(this.RETURN_VALUE, this.RETURN_VALUE_USER_EXISTS);

            }
            else {
               byte[] myPasswordHash = this.getUtility().hashString(myPassword);
               boolean retVal = this.getAuthenticatorStorage().createUser(myUserID,
                                                                          myDescription,
                                                                          myPasswordHash,
                                                                          myGSMSubscriberID);
               if(retVal) { // success, show receipt
                  returnTemplate = this.TEMPLATE_NAME_RECEIPT;
               }
               else {
                  ctx.put(this.RETURN_VALUE, this.RETURN_VALUE_ERROR_CREATING_USER);
               }
            }
         }
         else { // missing parameters
            ctx.put(this.RETURN_VALUE, this.RETURN_VALUE_MISSING_PARAMETERS);
         }
      }
      return returnTemplate;
    }

   /**
    * getNextPassword returns a new generated password
    *
    * @return String containing new generated password
    */

   protected String getNextPassword() {
      return Controller.getPasswordGenerator().nextPassword();
   }

   /**
    * putUserParameters puts common user parameters into the context. The
    * instance variables should be populated before this method is called
    */

   private void putUserParameters(Context ctx) {
      ctx.put(this.PARAMETER_USERID, this.myUserID);
      ctx.put(this.PARAMETER_PASSWORD, this.myPassword);
      ctx.put(this.PARAMETER_DESCRIPTION, this.myDescription);
      ctx.put(this.PARAMETER_GSMSUBSCRIBER_ID, this.myGSMSubscriberID);
   }
}
