
package org.nst.pasientlink.authenticator;

/**
 * <p>Title: TestFixture</p>
 * <p>Description: This class sets up the common fixture for unit tests</p>
 * <p>Copyright: Copyright (c) 2002</p>
 * <p>Copyright: Copyright (c) 2002</p>
 * <p>Company: Norwegian Centre for Telemedicine </p>
 * @author Thomas Strandens, Per Atle Bakkevoll
 * @version 1.0
 *
 */

import junit.framework.*;
import java.util.Properties;
import java.io.InputStream;
import java.io.IOException;

public class TestFixture extends TestCase {

  private Properties configuration;
  private Utility utility;
  private AuthenticatorStorage authenticatorStorage;
  private String testUserID = "unittestuser";
  private String testUserPasswordPlaintext = "drmovinckel"; // do not change without changing hash/hashBase64 version too!
  private String testUserDescription = "temporary unittest user - removed after tests have been run";
  private String testUserPasswordHashBASE64 = "rah/8Tuw0Y2Zf2SEAcPz+vMUb+8="; // string 'drmovinckel' SHA-1 hashed/BASE64-encoded
  private byte[] testUserPasswordHash;
  private String testUserGSMSubscriberID = "91305501"; //

  public TestFixture(String s) {
   super(s);
  }

  /**
   * Setup gets configuration and sets up AuthenticatorStorage and utility objects.
   * The method also tries to remove existing test users...
   *
   */

  protected void setUp() {
      this.utility = new Utility();
      this.authenticatorStorage = new AuthenticatorStorage(this.utility.getConfiguration());

      this.utility.setAuthenticatorStorage(this.authenticatorStorage);
      sun.misc.BASE64Decoder myDecoder = new sun.misc.BASE64Decoder();
      try {
         this.testUserPasswordHash = myDecoder.decodeBuffer(this.testUserPasswordHashBASE64);
      }
         catch (IOException e) {
      }
      // remove previous test user instances..
      this.removeTestUser();
  }

  /**
   * tearDown closes database connections etc.
   */

   protected void tearDown() {
   }

  /**
   * createTestUser creates test user. setUp() must have been called
   * (and not tearDown() after setUp())
   */

   protected boolean createTestUser() {
      return this.authenticatorStorage.createUser(this.testUserID,
                                                  this.testUserDescription,
                                                  this.testUserPasswordHash,
                                                  this.testUserGSMSubscriberID);
   }

   /**
    * removeTestUser removes test user.
    */

   protected boolean removeTestUser() {
      return this.authenticatorStorage.removeUser(this.testUserID);
   }

   /**
    * misc get-methods
    */

   protected AuthenticatorStorage getAuthenticatorStorage() {
      return this.authenticatorStorage;
   }

   protected Utility getUtility() {
      return this.utility;
   }


   protected String getTestUserID() {
      return this.testUserID;
   }

   protected String getTestUserPasswordPlaintext() {
      return this.testUserPasswordPlaintext;
   }

   protected String getTestUserDescription() {
      return this.testUserDescription;
   }

   protected byte[] getTestUserPasswordHash() {
      return this.testUserPasswordHash;
   }

   protected String getTestUserGSMSubscriberID() {
      return this.testUserGSMSubscriberID;
   }
}
